@@ -138,6 +138,7 @@ static void lobbyCommand_PrintHelp(uint32_t receiver)
 	sendRoomSystemMessageToSingleReceiver("Admin-only commands: (All slots count from 0)", receiver);
 	sendRoomSystemMessageToSingleReceiver(LOBBY_COMMAND_PREFIX "swap <slot-from> <slot-to> - Swap player/slot positions", receiver);
 	sendRoomSystemMessageToSingleReceiver(LOBBY_COMMAND_PREFIX "makespec <slot> - Move a player to spectators", receiver);
+	sendRoomSystemMessageToSingleReceiver(LOBBY_COMMAND_PREFIX "makeplayer s<slot> - Request to move a spectator to players", receiver);
 	sendRoomSystemMessageToSingleReceiver(LOBBY_COMMAND_PREFIX "kick <slot> - Kick a player; (or s<slot> for spectator - ex. s0)", receiver);
 	sendRoomSystemMessageToSingleReceiver(LOBBY_COMMAND_PREFIX "team <slot> <team> - Change team for player/slot", receiver);
 	sendRoomSystemMessageToSingleReceiver(LOBBY_COMMAND_PREFIX "base <base level> - Change base level (0, 1, 2)", receiver);
@@ -229,12 +230,13 @@ bool processChatLobbySlashCommands(const NetworkTextMessage& message, HostLobbyO
 	const auto& identity = getMultiStats(message.sender).identity;
 	std::string senderhash = identity.publicHashString(64);
 	std::string senderPublicKeyB64 = base64Encode(identity.toBytes(EcKey::Public));
+	std::string senderVerifiedStatus = (ingame.VerifiedIdentity[message.sender]) ? "V" : "?";
 	std::string sendername = NetPlay.players[message.sender].name;
 	std::string sendername64 = base64Encode(std::vector<unsigned char>(sendername.begin(), sendername.end()));
 	std::string messagetext = message.text;
 	std::string messagetext64 = base64Encode(std::vector<unsigned char>(messagetext.begin(), messagetext.end()));
 	debug(LOG_INFO, "message [%s] [%s]", senderhash.c_str(), message.text);
-	wz_command_interface_output("WZCHATCMD: %i %s %s %s %s %s\n", message.sender, NetPlay.players[message.sender].IPtextAddress, senderhash.c_str(), senderPublicKeyB64.c_str(), sendername64.c_str(), messagetext64.c_str());
+	wz_command_interface_output("WZCHATCMD: %i %s %s %s %s %s %s\n", message.sender, NetPlay.players[message.sender].IPtextAddress, senderhash.c_str(), senderPublicKeyB64.c_str(), sendername64.c_str(), messagetext64.c_str(), senderVerifiedStatus.c_str());
 	if (strcmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "help") == 0)
 	{
 		lobbyCommand_PrintHelp(static_cast<uint32_t>(message.sender));
@@ -253,7 +255,7 @@ bool processChatLobbySlashCommands(const NetworkTextMessage& message, HostLobbyO
 								NetPlay.players[message.sender].name);
 		sendRoomSystemMessageToSingleReceiver(msg.c_str(), message.sender);
 	}
-	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "team", 4) == 0)
+	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "team ", 5) == 0)
 	{
 		ADMIN_REQUIRED_FOR_COMMAND("team");
 		unsigned int s1 = 0, s2 = 0;
@@ -278,27 +280,40 @@ bool processChatLobbySlashCommands(const NetworkTextMessage& message, HostLobbyO
 		ADMIN_REQUIRED_FOR_COMMAND("hostexit");
 		cmdInterface.quitGame(5);
 	}
-	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "kick", 4) == 0)
+	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "kick ", 5) == 0 || strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "ban ", 4) == 0)
 	{
-		ADMIN_REQUIRED_FOR_COMMAND("kick");
+		bool isBan = strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "ban", 3) == 0;
+		if (!isBan)
+		{
+			ADMIN_REQUIRED_FOR_COMMAND("kick");
+		}
+		else
+		{
+			ADMIN_REQUIRED_FOR_COMMAND("ban");
+		}
+		std::string command = (!isBan) ? "kick" : "ban";
 		unsigned int playerPos = MAX_PLAYERS + 1;
 		unsigned int playerIdx = MAX_CONNECTED_PLAYERS + 1;
-		int r = sscanf(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "kick %u", &playerPos);
+		std::string commandParse = command + " %u";
+		int r = sscanf(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], commandParse.c_str(), &playerPos);
 		if (r == 1)
 		{
 			playerIdx = posToNetPlayer(playerPos);
 			if (playerIdx >= MAX_PLAYERS)
 			{
-				sendRoomNotifyMessage("Usage: " LOBBY_COMMAND_PREFIX "kick <slot>");
+				std::string msg = std::string("Usage: " LOBBY_COMMAND_PREFIX) + command + " <slot>";
+				sendRoomNotifyMessage(msg.c_str());
 				return false;
 			}
 		}
 		else
 		{
-			r = sscanf(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "kick s%u", &playerPos);
+			commandParse = command + " s%u";
+			r = sscanf(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], commandParse.c_str(), &playerPos);
 			if (r != 1 || playerPos >= MAX_SPECTATOR_SLOTS)
 			{
-				sendRoomNotifyMessage("Usage: " LOBBY_COMMAND_PREFIX "kick <slot>");
+				std::string msg = std::string("Usage: " LOBBY_COMMAND_PREFIX) + command + " <slot>";
+				sendRoomNotifyMessage(msg.c_str());
 				return false;
 			}
 			playerIdx = MAX_PLAYER_SLOTS + playerPos;
@@ -310,14 +325,14 @@ bool processChatLobbySlashCommands(const NetworkTextMessage& message, HostLobbyO
 			sendRoomSystemMessage("Can't kick the host.");
 			return false;
 		}
-		if (!cmdInterface.kickPlayer(playerIdx, _("Administrator has kicked you from the game.")))
+		if (!cmdInterface.kickPlayer(playerIdx, _("Administrator has kicked you from the game."), isBan))
 		{
 			std::string msg = astringf("Failed to kick %s: %u", (playerIdx < MAX_PLAYER_SLOTS) ? "player" : "spectator", playerPos);
 			sendRoomSystemMessage(msg.c_str());
 			return false;
 		}
 	}
-	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "swap", 4) == 0)
+	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "swap ", 5) == 0)
 	{
 		ADMIN_REQUIRED_FOR_COMMAND("swap");
 		unsigned int s1, s2;
@@ -351,7 +366,7 @@ bool processChatLobbySlashCommands(const NetworkTextMessage& message, HostLobbyO
 
 		sendRoomSystemMessage((std::string("Swapping player ")+std::to_string(s1)+" and "+std::to_string(s2)).c_str());
 	}
-	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "base", 4) == 0)
+	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "base ", 5) == 0)
 	{
 		ADMIN_REQUIRED_FOR_COMMAND("base");
 		int s1;
@@ -376,7 +391,7 @@ bool processChatLobbySlashCommands(const NetworkTextMessage& message, HostLobbyO
 
 		sendRoomSystemMessage((std::string("Starting base set to ")+std::to_string(s1)).c_str());
 	}
-	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "alliance", 8) == 0)
+	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "alliance ", 9) == 0)
 	{
 		ADMIN_REQUIRED_FOR_COMMAND("alliance");
 		int s1;
@@ -414,7 +429,7 @@ bool processChatLobbySlashCommands(const NetworkTextMessage& message, HostLobbyO
 			sendRoomSystemMessage((std::string("Alliance type set to ")+std::to_string(s1)).c_str());
 		}
 	}
-	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "scav", 4) == 0)
+	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "scav ", 5) == 0)
 	{
 		ADMIN_REQUIRED_FOR_COMMAND("scav");
 		int scavsValue;
@@ -440,7 +455,7 @@ bool processChatLobbySlashCommands(const NetworkTextMessage& message, HostLobbyO
 
 		sendRoomSystemMessage((std::string("Scavangers set to ")+std::to_string(scavsValue)).c_str());
 	}
-	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "makespec", 8) == 0)
+	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "makespec ", 9) == 0)
 	{
 		ADMIN_REQUIRED_FOR_COMMAND("makespec");
 		unsigned int playerPos = MAX_PLAYERS + 1;
@@ -470,6 +485,31 @@ bool processChatLobbySlashCommands(const NetworkTextMessage& message, HostLobbyO
 			return false;
 		}
 	}
+	else if (strncmp(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "makeplayer ", 11) == 0)
+	{
+		ADMIN_REQUIRED_FOR_COMMAND("makeplayer");
+		unsigned int playerPos = MAX_PLAYERS + 1;
+		int r = sscanf(&message.text[LOBBY_COMMAND_PREFIX_LENGTH], "makeplayer s%u", &playerPos);
+		if (r != 1 || playerPos >= MAX_SPECTATOR_SLOTS)
+		{
+			sendRoomNotifyMessage("Usage: " LOBBY_COMMAND_PREFIX "makeplayer s<spectator slot>");
+			return false;
+		}
+		unsigned int playerIdx = MAX_PLAYER_SLOTS + playerPos;
+		ASSERT_OR_RETURN(false, playerIdx < MAX_CONNECTED_PLAYERS, "Invalid index: %u", playerIdx);
+		if (playerIdx == NetPlay.hostPlayer)
+		{
+			// Can't move the host...
+			sendRoomSystemMessage("Can't move the host.");
+			return false;
+		}
+		if (!cmdInterface.requestMoveSpectatorToPlayers(playerIdx))
+		{
+			std::string msg = astringf("Failed to move player to spectators: %u", playerPos);
+			sendRoomSystemMessage(msg.c_str());
+			return false;
+		}
+	}
 	else
 	{
 		// unrecognized command - not handled
